@@ -10,13 +10,22 @@ int parse_htpl_ldap_search(STR, int);
 int parse_htpl_ldap_modify(STR, int);
 int parse_htpl_ldap_dosearch(STR, int);
 int parse_htpl_ldap_add(STR, int);
+int parse_htpl_rem(STR, int);
+int parse_htpl_rem___fwd(STR, int);
+int parse_htpl_rem___rev(STR, int);
 int parse_htpl_include(STR, int);
 int parse_htpl_default(STR, int);
 int parse_htpl_continue(STR, int);
 int parse_htpl_break(STR, int);
 int parse_htpl_text(STR, int);
+int parse_htpl_text_fixed(STR, int);
+int parse_htpl_text_records(STR, int);
 int parse_htpl_text_precsv(STR, int);
+int parse_htpl_text_prefixed(STR, int);
 int parse_htpl_text_flat(STR, int);
+int parse_htpl_text_template(STR, int);
+int parse_htpl_text_template___fwd(STR, int);
+int parse_htpl_text_template___rev(STR, int);
 int parse_htpl_text_read(STR, int);
 int parse_htpl_text_csv(STR, int);
 int parse_htpl_text_cube(STR, int);
@@ -30,6 +39,7 @@ int parse_htpl_for___rev(STR, int);
 int parse_htpl_time(STR, int);
 int parse_htpl_time_modified(STR, int);
 int parse_htpl_sql(STR, int);
+int parse_htpl_sql_batch(STR, int);
 int parse_htpl_sql_update(STR, int);
 int parse_htpl_sql_exec(STR, int);
 int parse_htpl_sql_modify(STR, int);
@@ -46,10 +56,16 @@ int parse_htpl_sql_insert(STR, int);
 int parse_htpl_sql_query(STR, int);
 int parse_htpl_sql_mysql(STR, int);
 int parse_htpl_sql_search(STR, int);
-int parse_htpl_sql_postgres(STR, int);
 int parse_htpl_sql_project(STR, int);
+int parse_htpl_sql_postgres(STR, int);
+int parse_htpl_sql_scope(STR, int);
+int parse_htpl_sql_scope_connect(STR, int);
+int parse_htpl_sql_scope_exec(STR, int);
+int parse_htpl_sql_scope_cursor(STR, int);
+int parse_htpl_sql_scope_retrieve(STR, int);
 int parse_htpl_sql_msql(STR, int);
 int parse_htpl_sql_cursor(STR, int);
+int parse_htpl_poof(STR, int);
 int parse_htpl_proc(STR, int);
 int parse_htpl_proc___fwd(STR, int);
 int parse_htpl_proc___rev(STR, int);
@@ -105,6 +121,11 @@ int parse_htpl_clsutils_other(STR, int);
 int parse_htpl_clsutils_imp(STR, int);
 int parse_htpl_clsutils_mine(STR, int);
 int parse_htpl_throw(STR, int);
+int parse_htpl_pts(STR, int);
+int parse_htpl_pts_set(STR, int);
+int parse_htpl_pts_create(STR, int);
+int parse_htpl_pts_pool(STR, int);
+int parse_htpl_pts_call(STR, int);
 int parse_htpl_project(STR, int);
 int parse_htpl_fetchcols(STR, int);
 int parse_htpl_call(STR, int);
@@ -159,4 +180,4 @@ extern char *scope_names[];
 extern int scope_ids[];
 #endif
 
-#define NUM_MACROS 122
+#define NUM_MACROS 143
